@@ -50,7 +50,7 @@ class TestConfigParser(unittest.TestCase, GbpLogTester):
             parser = GbpOptionParser('%scmd2' % prefix)
             self.assertEqual(parser.config['single_git_override_option1'], 'single_git_override_value1')
         for line in range(0, 2):
-            self._check_log(line, ".*Old style config section \[git-cmd2\] found please rename to \[cmd2\]")
+            self._check_log(line, r'.*Old style config section \[git-cmd2\] found please rename to \[cmd2\]')
 
     def test_single_gbp_override(self):
         """
@@ -60,7 +60,7 @@ class TestConfigParser(unittest.TestCase, GbpLogTester):
             parser = GbpOptionParser('%scmd3' % prefix)
             self.assertEqual(parser.config['single_gbp_override_option1'], 'single_gbp_override_value1')
         for line in range(0, 2):
-            self._check_log(line, ".*Old style config section \[gbp-cmd3\] found please rename to \[cmd3\]")
+            self._check_log(line, r'.*Old style config section \[gbp-cmd3\] found please rename to \[cmd3\]')
 
     def test_single_git_override_disabled_deprecations(self):
         """
